@@ -38,7 +38,7 @@
 /*#define DEBUG*/
 #include <libanjuta/anjuta-debug.h>
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -585,7 +585,7 @@ gdb_var_create (IAnjutaDebuggerVariableObject *variable, gpointer user_data, GEr
 					   VALUE_COLUMN, variable->value, -1);
 	
 
-	if (variable->children == -1)
+	if ((variable->children == -1) || variable->has_more)
 	{
 		/* Find the number of children */
 		DmaVariablePacket *pack_child =
@@ -922,7 +922,7 @@ debug_tree_add_dummy (DebugTree *tree, GtkTreeIter *parent)
 {
 	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree->view));
 	GtkTreeIter iter;
-	
+
 	gtk_tree_store_append(GTK_TREE_STORE(model), &iter, parent);
 	gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
 					   VARIABLE_COLUMN, "",
@@ -941,7 +941,7 @@ debug_tree_add_watch (DebugTree *tree, const IAnjutaDebuggerVariableObject* var,
 	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree->view));
 	GtkTreeIter iter;
 	DmaVariableData *data;
-	
+
 	/* Allocate data */
 	data = dma_variable_data_new(var->name, auto_update);
 	
@@ -972,7 +972,7 @@ debug_tree_add_watch (DebugTree *tree, const IAnjutaDebuggerVariableObject* var,
 			}
 			else
 			{
-				DEBUG_PRINT("YOu shouldn't read this, debug_tree_add_watch");
+				DEBUG_PRINT("%s", "You shouldn't read this, debug_tree_add_watch");
 				if (var->value == NULL)
 				{
 					/* Get value */
@@ -985,7 +985,7 @@ debug_tree_add_watch (DebugTree *tree, const IAnjutaDebuggerVariableObject* var,
 							(IAnjutaDebuggerCallback)gdb_var_evaluate_expression,
 							pack);
 				}
-				if (var->children == -1)
+				if ((var->children == -1) || var->has_more)
 				{
 					/* Get number of children */
 					DmaVariablePacket *pack =
