@@ -25,6 +25,8 @@
 #include <gtk/gtk.h>
 #include "gdbmi.h"
 
+#include "preferences.h"
+
 #include <libanjuta/interfaces/ianjuta-message-view.h>
 #include <libanjuta/interfaces/ianjuta-debugger.h>
 
@@ -51,11 +53,18 @@ typedef void (*DebuggerParserFunc) (Debugger *debugger,
 									const GList *cli_result,
 									GError* error);
 
+typedef enum
+{
+	DEBUGGER_COMMAND_NO_ERROR = 1 << 0,
+	DEBUGGER_COMMAND_KEEP_RESULT = 1 << 1,
+	DEBUGGER_COMMAND_PREPEND = 1 << 2,
+} DebuggerCommandFlags;
+
+
 struct _DebuggerCommand
 {
 	gchar *cmd;
-	gboolean suppress_error;
-	gboolean keep_result;
+	DebuggerCommandFlags flags;
 	DebuggerParserFunc parser;
 	IAnjutaDebuggerCallback callback;
 	gpointer user_data;
@@ -77,8 +86,13 @@ GType debugger_get_type (void);
 Debugger* debugger_new (GtkWindow *parent_win, GObject* instance);
 void debugger_free (Debugger *debugger);
 
-gboolean debugger_start (Debugger *debugger, const GList *search_dirs,
-							const gchar *prog, gboolean is_libtool_prog);
+gboolean debugger_set_pretty_printers (Debugger *debugger,
+									const GList *pretty_printers);
+
+gboolean debugger_start (Debugger *debugger,
+						const GList *search_dirs,
+						const gchar *prog,
+						gboolean is_libtool_prog);
 
 gboolean debugger_stop (Debugger *debugger);
 gboolean debugger_abort (Debugger *debugger);
@@ -124,7 +138,9 @@ void debugger_stepi_in (Debugger *debugger);
 void debugger_stepi_over (Debugger *debugger);
 void debugger_run_to_location (Debugger *debugger, const gchar *loc);
 void debugger_run_to_position (Debugger *debugger, const gchar *file, guint line);
+void debugger_run_from_position (Debugger *debugger, const gchar *file, guint line);
 void debugger_run_to_address (Debugger *debugger, gulong address);
+void debugger_run_from_address (Debugger *debugger, gulong address);
 
 /* Breakpoint */
 void debugger_add_breakpoint_at_line (Debugger *debugger, const gchar* file, guint line, IAnjutaDebuggerCallback callback, gpointer user_data);
@@ -163,7 +179,8 @@ void debugger_write_register (Debugger *debugger, const gchar *name, const gchar
 /* Stack */
 void debugger_list_argument (Debugger *debugger, IAnjutaDebuggerCallback func, gpointer user_data);
 void debugger_list_frame (Debugger *debugger, IAnjutaDebuggerCallback func, gpointer user_data);
-void debugger_set_frame (Debugger *debugger, guint frame);
+void debugger_set_frame (Debugger *debugger, gsize frame);
+void debugger_dump_stack_trace (Debugger *debugger, IAnjutaDebuggerCallback func, gpointer user_data);
 
 /* Thread */
 void debugger_list_thread (Debugger *debugger, IAnjutaDebuggerCallback func, gpointer user_data);
