@@ -472,6 +472,22 @@ idebugger_list_register (IAnjutaDebugger *plugin, IAnjutaDebuggerCallback callba
 	return FALSE;
 }
 
+static gboolean
+idebugger_run_from (IAnjutaDebugger *plugin, const gchar *file, gint line, GError **err)
+{
+	DEBUG_PRINT ("%s", "run_from: Not Implemented");
+
+	return FALSE;
+}
+
+static gboolean
+idebugger_dump_stack_trace (IAnjutaDebugger *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
+{
+	DEBUG_PRINT ("%s", "dump_stack_trace: Not Implemented");
+
+	return FALSE;
+}
+
 static gboolean
 idebugger_callback (IAnjutaDebugger *plugin, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
 {
@@ -511,6 +527,7 @@ idebugger_iface_init (IAnjutaDebuggerIface *iface)
 	iface->step_over = idebugger_step_over;
 	iface->step_out = idebugger_step_out;
 	iface->run_to = idebugger_run_to;
+	iface->run_from = idebugger_run_from;
 	iface->exit = idebugger_exit;
 	iface->interrupt = idebugger_interrupt;
 
@@ -535,6 +552,7 @@ idebugger_iface_init (IAnjutaDebuggerIface *iface)
 	iface->set_thread = idebugger_set_thread;
 	iface->info_thread = idebugger_info_thread;
 	iface->list_register = idebugger_list_register;
+	iface->dump_stack_trace = idebugger_dump_stack_trace;
 
 	iface->send_command = idebugger_send_command;
 
