@@ -66,6 +66,7 @@
 #define PROJECT_LIST "project_list"
 #define PROJECT_BOOK "project_book"
 #define PROPERTY_TABLE "property_table"
+#define ERROR_VBOX "error_vbox"
 #define ERROR_ICON "error_icon"
 #define ERROR_MESSAGE "error_message"
 #define ERROR_DETAIL "error_detail"
@@ -83,6 +84,8 @@ struct _NPWDruid
 	GtkWindow* window;
 	
 	GtkNotebook* project_book;
+	GtkVBox *error_vbox;
+	GtkWidget *error_extra_widget;
 	GtkImage *error_icon;
 	GtkLabel *error_message;
 	GtkWidget *error_detail;
@@ -115,7 +118,7 @@ enum {
 
 /* Fill dialog page */
 static void
-npw_druid_fill_error_page (NPWDruid* druid, GtkMessageType type, const gchar *detail, const gchar *mesg,...)
+npw_druid_fill_error_page (NPWDruid* druid, GtkWidget *extra_widget, GtkMessageType type, const gchar *detail, const gchar *mesg,...)
 {
 	GtkAssistant *assistant;
 	GtkWidget *page;
@@ -186,6 +189,19 @@ npw_druid_fill_error_page (NPWDruid* druid, GtkMessageType type, const gchar *de
 		label = GTK_LABEL (gtk_bin_get_child (GTK_BIN (druid->error_detail)));
 		gtk_label_set_text (label, detail);
 	}
+
+	if (druid->error_extra_widget)
+		gtk_widget_destroy (druid->error_extra_widget);
+	druid->error_extra_widget = NULL;
+
+	/* Set extra widget */
+	if (extra_widget)
+	{
+		gtk_box_pack_start (GTK_BOX (druid->error_vbox), extra_widget,
+							FALSE, FALSE, 10);
+		gtk_widget_show (extra_widget);
+		druid->error_extra_widget = extra_widget;
+	}
 }
 
 /* Create finish page
@@ -199,7 +215,7 @@ cb_druid_add_summary_property (NPWProperty* property, gpointer user_data)
 	if (npw_property_get_options (property) & NPW_SUMMARY_OPTION)
 	{
 		g_string_append_printf (text, "%s %s\n",
-								_(npw_property_get_label (property)), 
+								npw_property_get_label (property), 
 								npw_property_get_value (property));
 	}
 }
@@ -217,7 +233,7 @@ npw_druid_fill_summary_page (NPWDruid* druid)
 
 	/* The project type is translated too, it is something like
 	 * generic, GNOME applet, Makefile project... */
-	g_string_append_printf (text, _("Project Type: %s\n"), _(npw_header_get_name (druid->header)));
+	g_string_append_printf (text, _("Project Type: %s\n"), npw_header_get_name (druid->header));
 
 	for (i = 0; (page = g_queue_peek_nth (druid->page_list, i)) != NULL; ++i)
 	{
@@ -275,10 +291,11 @@ cb_druid_insert_project_icon (gpointer data, gpointer user_data)
 	gtk_list_store_append (store, &iter);
 	pixbuf = gdk_pixbuf_new_from_file (npw_header_get_iconfile (header), NULL);
 	gtk_list_store_set (store, &iter, PIXBUF_COLUMN, pixbuf,
-						TEXT_COLUMN, _(npw_header_get_name (header)),
-						DESC_COLUMN, _(npw_header_get_description (header)),
+						TEXT_COLUMN, npw_header_get_name (header),
+						DESC_COLUMN, npw_header_get_description (header),
 						DATA_COLUMN, header,
 						-1);
+	
 	g_object_unref (pixbuf);
 }
 
@@ -311,6 +328,8 @@ cb_druid_insert_project_page (gpointer value, gpointer user_data)
 	
 	/* Fill icon view */
 	view = GTK_ICON_VIEW (gtk_builder_get_object (builder, PROJECT_LIST));
+	gtk_icon_view_set_pixbuf_column (view, PIXBUF_COLUMN);
+	gtk_icon_view_set_markup_column (view, TEXT_COLUMN);
 	store = gtk_list_store_new (4, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
 	g_list_foreach (template_list, cb_druid_insert_project_icon, store); 
 	gtk_icon_view_set_model (view, GTK_TREE_MODEL (store));
@@ -338,7 +357,7 @@ cb_druid_insert_project_page (gpointer value, gpointer user_data)
 
 /* Fill project selection page */
 static gboolean
-npw_druid_fill_selection_page (NPWDruid* druid)
+npw_druid_fill_selection_page (NPWDruid* druid, const gchar *directory)
 {
 	gchar* dir;
 	const gchar * const * sys_dir;
@@ -351,23 +370,31 @@ npw_druid_fill_selection_page (NPWDruid* druid)
 	/* Create list of projects */
 	druid->header_list = npw_header_list_new ();	
 	
-	/* Read project template in user directory,
-	 * normally ~/.local/share/anjuta/project,
-	 * the first template read override the others */
-	dir = g_build_filename (g_get_user_data_dir (), "anjuta", "project", NULL);
-	npw_header_list_readdir (&druid->header_list, dir);
-	g_free (dir);
-	
-	/* Read project template in system directory */	
-	for (sys_dir = g_get_system_data_dirs (); *sys_dir != NULL; sys_dir++)
+	if (directory != NULL)
 	{
-		dir = g_build_filename (*sys_dir, "anjuta", "project", NULL);
-		npw_header_list_readdir (&druid->header_list, PROJECT_WIZARD_DIRECTORY);
-		g_free (dir);
+		/* Read project template only in specified directory */
+		npw_header_list_readdir (&druid->header_list, directory);
 	}
+	else
+	{
+		/* Read project template in user directory,
+		 * normally ~/.local/share/anjuta/project,
+		 * the first template read override the others */
+		dir = g_build_filename (g_get_user_data_dir (), "anjuta", "project", NULL);
+		npw_header_list_readdir (&druid->header_list, dir);
+		g_free (dir);
+	
+		/* Read project template in system directory */	
+		for (sys_dir = g_get_system_data_dirs (); *sys_dir != NULL; sys_dir++)
+		{
+			dir = g_build_filename (*sys_dir, "anjuta", "project", NULL);
+			npw_header_list_readdir (&druid->header_list, dir);
+			g_free (dir);
+		}
 
-	/* Read anjuta installation directory */
-	npw_header_list_readdir (&druid->header_list, PROJECT_WIZARD_DIRECTORY);
+		/* Read anjuta installation directory */
+		npw_header_list_readdir (&druid->header_list, PROJECT_WIZARD_DIRECTORY);
+	}
 	
 	if (g_list_length (druid->header_list) == 0)
 	{
@@ -392,6 +419,7 @@ typedef struct _NPWDruidAddPropertyData
 	NPWDruid* druid;
 	guint row;
 	GtkTable *table;
+	GtkWidget *first_entry;
 } NPWDruidAddPropertyData;
 
 static void
@@ -423,7 +451,7 @@ cb_druid_add_property (NPWProperty* property, gpointer user_data)
 
 		/* Add label and entry */
 		gtk_table_resize (data->table, data->row + 1, 2);
-		label = gtk_label_new (_(npw_property_get_label (property)));
+		label = gtk_label_new (npw_property_get_label (property));
 		gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 		gtk_misc_set_padding (GTK_MISC (label), 6, 6);
 		gtk_table_attach (data->table, label, 0, 1, data->row, data->row + 1,
@@ -432,6 +460,9 @@ cb_druid_add_property (NPWProperty* property, gpointer user_data)
 			(GtkAttachOptions)(GTK_EXPAND|GTK_FILL), (GtkAttachOptions)(0), 0, 0);
 		
 		data->row++;
+		
+		/* Set first entry */
+		if (data->first_entry == NULL) data->first_entry = entry;
 	}
 };
 
@@ -447,13 +478,20 @@ npw_druid_fill_property_page (NPWDruid* druid, NPWPage* page)
 	gtk_container_foreach (GTK_CONTAINER (npw_page_get_widget (page)), cb_druid_destroy_widget, NULL);
  		
 	/* Update title	*/
-	gtk_assistant_set_page_title (GTK_ASSISTANT (druid->window), widget, _(npw_page_get_label (page)));
+	gtk_assistant_set_page_title (GTK_ASSISTANT (druid->window), widget, npw_page_get_label (page));
 
 	/* Add new widget */
 	data.druid = druid;
 	data.row = 0;
 	data.table = GTK_TABLE (npw_page_get_widget (page));
+	data.first_entry = NULL;
 	npw_page_foreach_property (page, (GFunc)cb_druid_add_property, &data);
+
+	/* Move focus on first entry */
+	if (data.first_entry != NULL)
+	{
+		gtk_container_set_focus_child (GTK_CONTAINER (data.table), data.first_entry);
+	}
 	
 	gtk_widget_show_all (widget);
 }
@@ -573,7 +611,7 @@ cb_save_valid_property (NPWProperty* property, gpointer user_data)
 		{
 			g_string_append_printf (data->error,
 									_("\nField \"%s\" is mandatory. Please enter it."),
-									_(npw_property_get_label (property)));
+									npw_property_get_label (property));
 			npw_property_remove_value (property);
 		}
 	}
@@ -587,8 +625,13 @@ cb_save_valid_property (NPWProperty* property, gpointer user_data)
 		{
 		case NPW_FILENAME_RESTRICTION:
 			g_string_append_printf (data->error,
-									_("Field \"%s\" must start with a letter, a digit or an underscore and contains only letters, digits, underscore, minus and dot. Please fix it."),
-									_(npw_property_get_label (property)));
+									_("Field \"%s\" must start with a letter, a digit or an underscore and contain only letters, digits, underscore, minus and dot. Please fix it."),
+									npw_property_get_label (property));
+			break;
+		case NPW_DIRECTORY_RESTRICTION:
+			g_string_append_printf (data->error,
+									_("Field \"%s\" must start with a letter, a digit, an underscore or a directory separator and contain only letters, digits, underscore, directory separator, minus and dot. Please fix it."),
+									npw_property_get_label (property));
 			break;
 		default:
 			g_string_append_printf (data->error,
@@ -648,7 +691,7 @@ npw_druid_save_valid_values (NPWDruid* druid)
 	
 	if (data.error->len)
 	{
-		npw_druid_fill_error_page (druid,
+		npw_druid_fill_error_page (druid, NULL,
 								   GTK_MESSAGE_ERROR,
 								   NULL,
 									"<b>%s</b>\n\n%s",
@@ -659,7 +702,7 @@ npw_druid_save_valid_values (NPWDruid* druid)
 	}
 	else if (data.warning->len)
 	{
-		npw_druid_fill_error_page (druid,
+		npw_druid_fill_error_page (druid, NULL,
 								   GTK_MESSAGE_WARNING,
 								   NULL,
 									"<b>%s</b>\n\n%s",
@@ -753,15 +796,66 @@ on_druid_parse_page (const gchar* output, gpointer data)
 	npw_page_parser_parse (parser, output, strlen (output), NULL);
 }
 
+static void
+strip_package_version_info (gpointer data, gpointer user_data)
+{
+	gchar * const pkg = (gchar *) data;
+
+	if (!data)
+		return;
+	g_strdelimit (pkg, " ", '\0');
+}
+
+static void
+on_install_button_clicked (GtkWidget *button, NPWDruid *druid)
+{
+	GList *missing_programs, *missing_packages;
+	GList *missing_files = NULL;
+
+	missing_programs = npw_header_check_required_programs (druid->header);
+	missing_packages = npw_header_check_required_packages (druid->header);
+
+	/*
+	 * FIXME: packagekit only allows search by absolute path, so we must
+	 * come up one. Unfortunately, hardcoding "/usr" prefix seems to be
+	 * the only sane way since most distros install there. Using anjuta
+	 * build prefix isn't any better since anjuta can be installed any
+	 * where irrespective of distro standandard prefix. If there is a
+	 * dynamic way to know it, we should try that (perhaps by doing
+	 * `which <some ubiquitous program>`).
+	 */
+	anjuta_util_glist_strings_prefix (missing_programs, "/usr/bin/");
+
+	g_list_foreach (missing_packages, (GFunc) strip_package_version_info,
+					NULL);
+	anjuta_util_glist_strings_prefix (missing_packages,
+									  "/usr/lib/pkgconfig/");
+	anjuta_util_glist_strings_sufix (missing_packages, ".pc");
+
+	missing_files = g_list_concat (missing_programs, missing_packages);
+
+	if (missing_files)
+	{
+		gchar * missing_names = NULL;
+
+		missing_names = anjuta_util_glist_strings_join (missing_files, ", ");
+		anjuta_util_install_files (missing_names);
+
+		if (missing_names)
+			g_free (missing_names);
+		anjuta_util_glist_strings_free (missing_files);
+	}
+}
+
 static gboolean
 check_and_warn_missing (NPWDruid *druid)
 {
 	GList *missing_programs, *missing_packages;
 	GString *missing_message = NULL;
-	
+
 	missing_programs = npw_header_check_required_programs (druid->header);
 	missing_packages = npw_header_check_required_packages (druid->header);
-	
+
 	if (missing_programs || missing_packages)
 	{
 		missing_message = g_string_new (NULL);
@@ -775,7 +869,7 @@ check_and_warn_missing (NPWDruid *druid)
 		g_string_append_printf (missing_message,
 								_("\nMissing programs: %s."), missing_progs);
 		g_free (missing_progs);
-		g_list_free (missing_programs);
+		anjuta_util_glist_strings_free (missing_programs);
 	}
 	
 	if (missing_packages)
@@ -786,24 +880,35 @@ check_and_warn_missing (NPWDruid *druid)
 		g_string_append_printf (missing_message,
 								_("\nMissing packages: %s."), missing_pkgs);
 		g_free (missing_pkgs);
-		g_list_free (missing_packages);
+		anjuta_util_glist_strings_free (missing_packages);
 	}
 	
 	if (missing_message)
 	{
+		GtkWidget *hbox, *install_button;
 		g_string_prepend (missing_message, _(
 		 "Some important programs or development packages required to build "
 		 "this project are missing. Please make sure they are "
 		 "installed properly before generating the project.\n"));
 
-		npw_druid_fill_error_page (druid,
+		hbox = gtk_hbox_new (FALSE, 0);
+		gtk_widget_show (hbox);
+
+		install_button =
+			gtk_button_new_with_label (_("Install missing packages"));
+		gtk_box_pack_end (GTK_BOX (hbox), install_button, FALSE, FALSE, 10);
+		g_signal_connect (install_button, "clicked",
+						  G_CALLBACK (on_install_button_clicked), druid);
+		gtk_widget_show (install_button);
+
+		npw_druid_fill_error_page (druid, hbox,
 								   GTK_MESSAGE_WARNING,
 								  _("The missing programs are usually part of some distrubution "
-									"packages and can be searched in your Application Manager. "
+									"packages and can be searched for in your Application Manager. "
 									"Similarly, the development packages are contained in special "
-									"packages that your distribution provide to allow development "
-									"of projects based on them. They usually end with -dev or "
-									"-devel suffix in package names and can be found by searching "
+									"packages that your distribution provides to allow development "
+									"of projects based on them. They usually end with a \"-dev\" or "
+									"\"-devel\" suffix in package names and can be found by searching "
 									"in your Application Manager."),
 									"<b>%s</b>\n\n%s",
 									_("Missing components"),
@@ -922,7 +1027,7 @@ on_druid_finish (GtkAssistant* assistant, NPWDruid* druid)
 }
 
 static GtkWidget*
-npw_druid_create_assistant (NPWDruid* druid)
+npw_druid_create_assistant (NPWDruid* druid, const gchar *directory)
 {
 	AnjutaShell *shell;
 	GtkBuilder *builder;
@@ -944,6 +1049,7 @@ npw_druid_create_assistant (NPWDruid* druid)
 	assistant = GTK_ASSISTANT (gtk_builder_get_object (builder, NEW_PROJECT_DIALOG));
 	druid->window = GTK_WINDOW (assistant);
 	druid->project_book = GTK_NOTEBOOK (gtk_builder_get_object (builder, PROJECT_BOOK));
+	druid->error_vbox = GTK_VBOX (gtk_builder_get_object (builder, ERROR_VBOX));
 	druid->error_icon = GTK_IMAGE (gtk_builder_get_object (builder, ERROR_ICON));
 	druid->error_message = GTK_LABEL (gtk_builder_get_object (builder, ERROR_MESSAGE));
 	druid->error_detail = GTK_WIDGET (gtk_builder_get_object (builder, ERROR_DETAIL));
@@ -959,7 +1065,7 @@ npw_druid_create_assistant (NPWDruid* druid)
 	g_signal_connect(G_OBJECT(assistant), "key-press-event", G_CALLBACK(on_project_wizard_key_press_event), druid);
 
 	/* Setup project selection page */
-	if (!npw_druid_fill_selection_page (druid))
+	if (!npw_druid_fill_selection_page (druid, directory))
 	{
 		return NULL;
 	}
@@ -1030,14 +1136,14 @@ npw_druid_add_default_property (NPWDruid* druid)
  *---------------------------------------------------------------------------*/
 
 NPWDruid*
-npw_druid_new (NPWPlugin* plugin)
+npw_druid_new (NPWPlugin* plugin, const gchar *directory)
 {
 	NPWDruid* druid;
 
 	/* Check if autogen is present */
 	if (!npw_check_autogen())
 	{
-		anjuta_util_dialog_error (NULL, _("Could not find autogen version 5, please install the autogen package. You can get it from http://autogen.sourceforge.net"));
+		anjuta_util_dialog_error (NULL, _("Could not find autogen version 5; please install the autogen package. You can get it from http://autogen.sourceforge.net."));
 		return NULL;
 	}	
 
@@ -1049,8 +1155,9 @@ npw_druid_new (NPWPlugin* plugin)
 	druid->values = npw_value_heap_new ();
 	druid->gen = npw_autogen_new ();
 	druid->plugin = plugin;
-	
-	if (npw_druid_create_assistant (druid) == NULL)
+	druid->error_extra_widget = NULL;
+
+	if (npw_druid_create_assistant (druid, directory) == NULL)
 	{
 		npw_druid_free (druid);
 		
